.. light-curve-python documentation master file, created by
   sphinx-quickstart on Thu Sep 24 16:05:39 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to light-curve-python's documentation!
==============================================

``light_curve``
---------------

.. automodule:: light_curve.light_curve
   :members:
   :undoc-members:

``antifeatures``
----------------

.. automodule:: light_curve.light_curve.antifeatures
   :members:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
